unit ESDigitalClock;

interface

{$R ESControls.dcr}

uses
  SysUtils, Classes, Controls, StdCtrls, ExtCtrls, Windows;

type
  TESDigitalClock = class(TCustomLabel)
  private
    { Private declarations }
    FTimer: TTimer;
    FOnUpdate: TNotifyEvent;
    procedure UpdateCaption(Sender: TObject);
    function GetEnableUpdate: Boolean;
    procedure SetEnableUpdate(const Value: Boolean);
    function GetTime: TTime;
    function GetTimeStr: String;
    function GetUpdateInterval: Cardinal;
    procedure SetUpdateInterval(const Value: Cardinal);
  protected
    { Protected declarations }
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
    procedure UpdateTime;
    property TimeStr: String read GetTimeStr;
    property Time: TTime read GetTime;
  published
    { Published declarations }
    property OnUpdate: TNotifyEvent read FOnUpdate write FOnUpdate;
    property EnableUpdate: Boolean read GetEnableUpdate write SetEnableUpdate default True;
    property UpdateInterval: Cardinal read GetUpdateInterval write SetUpdateInterval default 1000;
    property Align;
    property Alignment;
    property Anchors;
    property AutoSize;
    property BiDiMode;
    property Color nodefault;
    property Constraints;
    property DragCursor;
    property DragKind;
    property DragMode;
    property Enabled;
    property FocusControl;
    property Font;
    property ParentBiDiMode;
    property ParentColor;
    property ParentFont;
    property ParentShowHint;
    property PopupMenu;
    property ShowAccelChar;
    property ShowHint;
    property Transparent;
    property Layout;
    property Visible;
    property WordWrap;
    property OnClick;
    property OnContextPopup;
    property OnDblClick;
    property OnDragDrop;
    property OnDragOver;
    property OnEndDock;
    property OnEndDrag;
    property OnMouseDown;
    property OnMouseMove;
    property OnMouseUp;
    property OnMouseEnter;
    property OnMouseLeave;
    property OnStartDock;
    property OnStartDrag;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('ES komponente', [TESDigitalClock]);
end;

{ TESDigitalClock }

constructor TESDigitalClock.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  UpdateTime;
  FTimer := TTimer.Create(Self);
  FTimer.OnTimer := UpdateCaption;
end;

destructor TESDigitalClock.Destroy;
begin
  FTimer.Free;
  inherited;
end;

function TESDigitalClock.GetEnableUpdate: Boolean;
begin
  Result := FTimer.Enabled;
end;

function TESDigitalClock.GetTime: TTime;
begin
  Result := StrToTime(Caption);
end;

function TESDigitalClock.GetTimeStr: String;
begin
  Result := Caption;
end;

function TESDigitalClock.GetUpdateInterval: Cardinal;
begin
  Result := FTimer.Interval;
end;

procedure TESDigitalClock.SetEnableUpdate(const Value: Boolean);
begin
  FTimer.Enabled := Value;
end;

procedure TESDigitalClock.SetUpdateInterval(const Value: Cardinal);
begin
  FTimer.Interval := Value;
end;

procedure TESDigitalClock.UpdateCaption(Sender: TObject);
begin
  Caption := TimeToStr(SysUtils.Time);
  If (Assigned(FOnUpdate)) and
     (Not (csDesigning in ComponentState)) then
  FOnUpdate(Self);
end;

procedure TESDigitalClock.UpdateTime;
begin
  UpdateCaption(Self);
end;

end.
